sqlobject.dberrors module — SQLObject 3.9.1 documentation

# sqlobject.dberrors module

dberrors: database exception classes for SQLObject.

These classes are dictated by the DB API v2.0, see: https://wiki.python.org/moin/DatabaseProgramming

exception `sqlobject.dberrors.` `DataError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `DatabaseError`

  Bases: `sqlobject.dberrors.Error`

exception `sqlobject.dberrors.` `DuplicateEntryError`

  Bases: `sqlobject.dberrors.IntegrityError`

exception `sqlobject.dberrors.` `Error`

  Bases: `Exception`

exception `sqlobject.dberrors.` `IntegrityError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `InterfaceError`

  Bases: `sqlobject.dberrors.Error`

exception `sqlobject.dberrors.` `InternalError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `NotSupportedError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `OperationalError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `ProgrammingError`

  Bases: `sqlobject.dberrors.DatabaseError`

exception `sqlobject.dberrors.` `Warning`

  Bases: `Exception`